Monopile Installation API
=========================

For detailed methodology, please see
:doc:`Monopile Installation Methodology <doc_MonopileInstall>`.

.. automodule:: ORBIT.phases.install.monopile_install.standard
   :members:
   :exclude-members: extract_vessel_specs

.. automodule:: ORBIT.phases.install.monopile_install._common
   :members:

.. automodule:: ORBIT.phases.install.monopile_install._single_wtiv
   :members:

.. automodule:: ORBIT.phases.install.monopile_install._wtiv_with_feeders
   :members:
